@@ -61,7 +61,7 @@ class Pg:
     async def limit_fetchs(self, guild: discord.Guild, limit, offset):
         "テーブルのデータを制限数付きで取得する"
 
-        contents = await self.pool.fetch('select * from tags where server_id =$1 limit $2 OFFSET $3', guild.id, limit, offset)
+        contents = await self.pool.fetch(f'select * from {self.table} where server =$1 limit $2 OFFSET $3', guild.id, limit, offset)
         return contents
         
 
